@@ -454,7 +454,7 @@ class Session:
                         return api_model_obj.embedded.udmobject, status, header
                     else:
                         # resource
-                        _dn = None if status == 204 else api_model_obj.dn
+                        _dn = None if status == 204 else getattr(api_model_obj, "dn", None)
                         logger.debug(
                             "%r %r -> %s(**%r) -> %s(%r) [%r]",
                             operation,
@@ -865,6 +865,11 @@ class UdmObject(BaseObject):
         :return: the new ApiModel object from the UDM REST API
         :rtype: ApiModel
         """
+        # The `language` argument is now always set, to make sure the language does not switch during
+        # a move operation. The UDM REST API has separate process trees per language, and redirect URLs
+        # are not shared between them.
+        language = language or "en-US"
+
         # workaround for Bug #50262: use PUT instead of PATCH
         self._api_obj.position = position
         try:
@@ -917,6 +922,7 @@ class UdmObject(BaseObject):
                     self._udm_module.session.openapi_client_config.username,
                     self._udm_module.session.openapi_client_config.password,
                 ),
+                headers={"Accept-Language": language},
             )
             try:
                 sleep_time = float(resp.headers["Retry-After"])
